==> haskell-tamarin-prover-export-1.10.0-116-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-export.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tamarin-prover-export
version:              1.10.0
visibility:           public
id:                   tamarin-prover-export-1.10.0-HMFaF92WvgR54tlYx94ozw
key:                  tamarin-prover-export-1.10.0-HMFaF92WvgR54tlYx94ozw
license:              GPL-3.0-only
copyright:
    Robert Künnemann, CISPA-Helmholtz-Centre Saarbrücken, 2019
    Charlie Jacomme, LSV, 2019

maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Charlie Jacomme <charlie.jacomme@lsv.fr>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Library for export of processes in the Sapic calculus to the Proverif calculus

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
    .

category:             Theorem Provers
abi:                  fc1776251655e78cf14272b67c57c959
exposed:              True
exposed-modules:      Export
hidden-modules:       RuleTranslation
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tamarin-prover-export-1.10.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tamarin-prover-export-1.10.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tamarin-prover-export-1.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-export
hs-libraries:         HStamarin-prover-export-1.10.0-HMFaF92WvgR54tlYx94ozw
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    tamarin-prover-sapic-1.10.0-1Z6H6HwswS3EOAfRoKCvne
    tamarin-prover-term-1.10.0-IUdnTshWpyz5ZraNmmXHqM
    tamarin-prover-theory-1.10.0-Lu42fZUIMf1AkrCMEx42sl
    tamarin-prover-utils-1.10.0-51wdse7rMdv3WKKkJspzRr text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-export/html/tamarin-prover-export.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-export/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-export-1.10.0-137-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-export.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tamarin-prover-export
version:              1.10.0
visibility:           public
id:                   tamarin-prover-export-1.10.0-4FMWQwNO5F3KOATQ5OEHxk
key:                  tamarin-prover-export-1.10.0-4FMWQwNO5F3KOATQ5OEHxk
license:              GPL-3.0-only
copyright:
    Robert Künnemann, CISPA-Helmholtz-Centre Saarbrücken, 2019
    Charlie Jacomme, LSV, 2019

maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Charlie Jacomme <charlie.jacomme@lsv.fr>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Library for export of processes in the Sapic calculus to the Proverif calculus

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
    .

category:             Theorem Provers
abi:                  76e3d47f98506830d3bdb3b4bb8d3c9c
exposed:              True
exposed-modules:      Export
hidden-modules:       RuleTranslation
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tamarin-prover-export-1.10.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tamarin-prover-export-1.10.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tamarin-prover-export-1.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-export
hs-libraries:         HStamarin-prover-export-1.10.0-4FMWQwNO5F3KOATQ5OEHxk
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    tamarin-prover-sapic-1.10.0-IqWYGYlAlSfJnCkzuHlNyL
    tamarin-prover-term-1.10.0-AJ7gDCvTd2CK9RSSG7W2Ws
    tamarin-prover-theory-1.10.0-EMek1fgRerQ7WUxWUrUp1y
    tamarin-prover-utils-1.10.0-Gur3qLb0EqH1Sox8VJiqgv text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-export/html/tamarin-prover-export.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-export/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
